@@ -1,4 +1,4 @@
-/* $Id: testcodelength.c,v 1.1 2008/10/06 22:04:06 nanard Exp $ */
+/* $Id: testcodelength.c,v 1.2 2011/06/17 23:05:00 nanard Exp $ */
 /* Project : miniupnp
  * Author : Thomas BERNARD
  * copyright (c) 2005-2008 Thomas Bernard
@@ -13,9 +13,9 @@ int main(int argc, char * * argv)
 	unsigned char * p;
 	long i, j;
 
-	for(i = 1; i < 1000000000; i = i * 7) {
+	for(i = 1; i < 1000000000; i *= 2) {
 		/* encode i, decode to j */
-		/*printf("%ld ", i);*/
+		printf("%ld ", i);
 		p = buf;
 		CODELENGTH(i, p);
 		p = buf;
